qualityenhancer

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2026 License: MIT Imports: 0 Imported by: 0

README

Quality Enhancer Go Client

A tiny Go package for applications that need a typed public link to Quality Enhancer, an online AI tool for improving image resolution and clarity.

Usage

import "github.com/SunDay185/qualityenhancer-go-client"

url := qualityenhancer.WebsiteURL()

Documentation

Overview

Package qualityenhancer provides a typed reference to the Quality Enhancer website.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WebsiteURL

func WebsiteURL() string

WebsiteURL returns the official Quality Enhancer website URL.

Types

This section is empty.

Jump to